@@ -27,11 +27,6 @@ class Ohai::Application
     :long        => "--directory DIRECTORY",
     :description => "A directory to add to the Ohai search path"
 
-  option :file,
-    :short       => "-f FILE",
-    :long        => "--file FILE",
-    :description => "A file to run Ohai against"
-
   option :log_level,
     :short        => "-l LEVEL",
     :long         => "--log_level LEVEL",
@@ -56,7 +51,7 @@ class Ohai::Application
   option :version,
     :short        => "-v",
     :long         => "--version",
-    :description  => "Show chef version",
+    :description  => "Show Ohai version",
     :boolean      => true,
     :proc         => lambda {|v| puts "Ohai: #{::Ohai::VERSION}"},
     :exit         => 0
@@ -77,6 +72,7 @@ class Ohai::Application
 
   def configure_ohai
     @attributes = parse_options
+    @attributes = nil if @attributes.empty?
 
     Ohai::Config.merge!(config)
     if Ohai::Config[:directory]
@@ -91,12 +87,9 @@ class Ohai::Application
 
   def run_application
     ohai = Ohai::System.new
-    if Ohai::Config[:file]
-      ohai.from_file(Ohai::Config[:file])
-    else
-      ohai.all_plugins
-    end
-    if @attributes.length > 0
+    ohai.all_plugins(@attributes)
+
+    if @attributes
       @attributes.each do |a|
         puts ohai.attributes_print(a)
       end
