@@ -6,9 +6,9 @@
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -21,7 +21,7 @@ require 'mixlib/config'
 module Ohai
   class Config
     extend Mixlib::Config
-    
+
     # from chef/config.rb, should maybe be moved to mixlib-config?
     def self.platform_specific_path(path)
       if RUBY_PLATFORM =~ /mswin|mingw|windows/
@@ -32,12 +32,12 @@ module Ohai
       end
       path
     end
-    
 
-    log_level :info
-    log_location STDOUT
-    plugin_path [ File.expand_path(File.join(File.dirname(__FILE__), 'plugins'))]
-    disabled_plugins []
-    hints_path [ platform_specific_path('/etc/chef/ohai/hints') ]
+
+    default :log_level, :info
+    default :log_location, STDERR
+    default :plugin_path, [ File.expand_path(File.join(File.dirname(__FILE__), 'plugins'))]
+    default :disabled_plugins, []
+    default(:hints_path) { [ platform_specific_path('/etc/chef/ohai/hints') ] }
   end
 end
