@@ -16,7 +16,14 @@
 # limitations under the License.
 #
 
-provides "platform", "platform_version"
+Ohai.plugin(:Platform) do
+  provides "platform", "platform_version", "platform_family"
 
-platform from("uname -s").downcase
-platform_version from("uname -r")
+  collect_data(:netbsd) do
+    so = shell_out("uname -s")
+    platform so.stdout.split($/)[0].downcase
+    so = shell_out("uname -r")
+    platform_version so.stdout.split($/)[0]
+    platform_family "netbsd"
+  end
+end
