@@ -1,6 +1,8 @@
 #
 # Author:: Doug MacEachern <dougm@vmware.com>
+# Author:: Tim Smith <tim@cozy.co>
 # Copyright:: Copyright (c) 2009 VMware, Inc.
+# Copyright:: Copyright (c) 2014 Cozy Services, Ltd.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,21 +18,29 @@
 # limitations under the License.
 #
 
-provides "languages/php"
+Ohai.plugin(:PHP) do
+  provides "languages/php"
 
-require_plugin "languages"
+  depends "languages"
 
-output = nil
+  collect_data do
+    php = Mash.new
 
-php = Mash.new
+    so = shell_out("php -v")
+    if so.exitstatus == 0
+      so.stdout.each_line do |line|
+        case line
+        when /PHP (\S+).+built: ([^)]+)/
+          php[:version] = $1
+          php[:builddate] = $2
+        when /Zend Engine v([^\s]+),/
+          php[:zend_engine_version] = $1
+        when /Zend OPcache v([^\s]+),/
+          php[:zend_opcache_version] = $1
+        end
+      end
 
-status, stdout, stderr = run_command(:no_status_check => true, :command => "php -v")
-if status == 0
-  output = stdout.split
-  if output.length >= 6
-    php[:version] = output[1]
-    php[:builddate] = "%s %s %s" % [output[4],output[5],output[6]]
+      languages[:php] = php if php[:version]
+    end
   end
-  languages[:php] = php if php[:version]
 end
-
