@@ -6,9 +6,9 @@
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,22 +16,26 @@
 # limitations under the License.
 #
 
-provides "languages/python"
+Ohai.plugin(:Python) do
+  provides "languages/python"
 
-require_plugin "languages"
+  depends "languages"
 
-output = nil
+  collect_data do
+    output = nil
 
-python = Mash.new
+    python = Mash.new
 
-status, stdout, stderr = run_command(:no_status_check => true, :command => "python -c \"import sys; print sys.version\"")
+    so = shell_out("python -c \"import sys; print (sys.version)\"")
 
-if status == 0
-  output = stdout.split
-  python[:version] = output[0]
-  if output.length >= 6
-    python[:builddate] = "%s %s %s %s" % [output[2],output[3],output[4],output[5].gsub!(/\)/,'')]
+    if so.exitstatus == 0
+      output = so.stdout.split
+      python[:version] = output[0]
+      if output.length >= 6
+        python[:builddate] = "%s %s %s %s" % [output[2],output[3],output[4],output[5].gsub!(/\)/,'')]
+      end
+
+      languages[:python] = python if python[:version] and python[:builddate]
+    end
   end
-
-  languages[:python] = python if python[:version] and python[:builddate]
 end
